==> haskell-tasty-th-0.1.7-33-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-th.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-th
version: 0.1.7
id: tasty-th-0.1.7-8pjEVpJc6deDgsBmJav5OC
key: tasty-th-0.1.7-8pjEVpJc6deDgsBmJav5OC
license: BSD-3-Clause
maintainer: Benno Fünfstück <benno.fuenfstueck@gmail.com>
author: Oscar Finnsson & Emil Nordling & Benno Fünfstück
homepage: http://github.com/bennofs/tasty-th
synopsis: Automatic tasty test case discovery using TH
description:
    Generate tasty TestTrees automatically with TemplateHaskell. See the README for example usage.
category: Testing
abi: a9f17ea026176bb0ca6c6a3ddbe322c9
exposed: True
exposed-modules:
    Test.Tasty.TH
import-dirs: /usr/lib/ghc-8.4.3/site-local/tasty-th-0.1.7
library-dirs: /usr/lib/ghc-8.4.3/site-local/tasty-th-0.1.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/tasty-th-0.1.7
hs-libraries: HStasty-th-0.1.7-8pjEVpJc6deDgsBmJav5OC
depends:
    base-4.11.1.0 haskell-src-exts-1.20.2-G3Ml6HbnqnN7z120FmAg0n
    tasty-1.1.0.3-47QwUInRtOzF3zSlr6CCJg template-haskell-2.13.0.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             haskell-src-exts-1.20.2-G3Ml6HbnqnN7z120FmAg0n=9fc9240c296c3256ebefb2c3beb011a7
             tasty-1.1.0.3-47QwUInRtOzF3zSlr6CCJg=2e6555b026876c59a316d2124bf273ef
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
haddock-interfaces: /usr/share/doc/haskell-tasty-th/html/tasty-th.haddock
haddock-html: /usr/share/doc/haskell-tasty-th/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-th-0.1.7-34-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-th.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-th
version: 0.1.7
id: tasty-th-0.1.7-1t55prNhQiV1ZAplC4h80O
key: tasty-th-0.1.7-1t55prNhQiV1ZAplC4h80O
license: BSD-3-Clause
maintainer: Benno Fünfstück <benno.fuenfstueck@gmail.com>
author: Oscar Finnsson & Emil Nordling & Benno Fünfstück
homepage: http://github.com/bennofs/tasty-th
synopsis: Automatic tasty test case discovery using TH
description:
    Generate tasty TestTrees automatically with TemplateHaskell. See the README for example usage.
category: Testing
abi: b26f166bed44c74a96b1b72bc376fb1c
exposed: True
exposed-modules:
    Test.Tasty.TH
import-dirs: /usr/lib/ghc-8.4.3/site-local/tasty-th-0.1.7
library-dirs: /usr/lib/ghc-8.4.3/site-local/tasty-th-0.1.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/tasty-th-0.1.7
hs-libraries: HStasty-th-0.1.7-1t55prNhQiV1ZAplC4h80O
depends:
    base-4.11.1.0 haskell-src-exts-1.20.2-2zv4TjJLcP4GWvkOUtOP0Z
    tasty-1.1.0.3-KUFSSP3U4ny9AQF2XUXxIK template-haskell-2.13.0.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             haskell-src-exts-1.20.2-2zv4TjJLcP4GWvkOUtOP0Z=60d4cdb6c821868fcfb451abd40f3254
             tasty-1.1.0.3-KUFSSP3U4ny9AQF2XUXxIK=b3b38fe9dbf8881a7eed1fb4b5bf8074
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
haddock-interfaces: /usr/share/doc/haskell-tasty-th/html/tasty-th.haddock
haddock-html: /usr/share/doc/haskell-tasty-th/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
